@@ -6,10 +6,11 @@ import bjson
 import logging
 import random
 import socket
+import socks
 import zlib
 import selectors
 from time import time, sleep
-from threading import Thread, Lock, Event
+from threading import Thread, current_thread, Lock, Event
 from nem_ed25519.base import Encryption
 from p2p_python.tool.traffic import Traffic
 from p2p_python.tool.utils import AESCipher, QueueSystem
@@ -88,12 +89,12 @@ class Core:
                 msg_len = msg[0]
                 msg_name, msg_body = msg[1:msg_len+1], msg[msg_len+1:]
                 user = self.name2user(msg_name.decode())
-                if user is None or not user.p2p_udp_accept:
+                if user is None:
                     return
                 self.traffic.put_traffic_down(msg_body)
                 msg_body = AESCipher.decrypt(key=user.aeskey, enc=msg_body)
                 if msg_body == b'Ping':
-                    logging.debug("Get udp accept from {}".format(user))
+                    logging.info("Get udp accept from {}".format(user))
                     self.send_msg_body(msg_body=b'Pong', user=user)
                 else:
                     logging.debug("Get udp packet from {}".format(user))
@@ -173,13 +174,15 @@ class Core:
         assert s_family in (socket.AF_INET, socket.AF_INET6, socket.AF_UNSPEC)
         self.traffic.start()
         # Pooling connection
-        if not V.P2P_ACCEPT:
-            logging.info('You set p2p accept flag False.')
-        else:
-            # create server ipv4/ipv6
+        if V.P2P_ACCEPT:
             create_tcp_server_socks()
+        if V.P2P_UDP_ACCEPT:
             create_udp_server_socks()
+        # listen socket ipv4/ipv6
+        if V.P2P_ACCEPT or V.P2P_UDP_ACCEPT:
             Thread(target=sock_listen_loop, name='Listen', daemon=True).start()
+        else:
+            logging.info('You set p2p accept flag False.')
         self.f_running = True
 
     def get_server_header(self):
@@ -200,7 +203,13 @@ class Core:
                 if host_port[0] in ban_address:
                     return False  # baned address
                 try:
-                    sock = socket.socket(af, socktype, proto)
+                    if V.TOR_CONNECTION:
+                        if af != socket.AF_INET:
+                            continue
+                        sock = socks.socksocket()
+                        sock.setproxy(socks.PROXY_TYPE_SOCKS5, V.TOR_CONNECTION[0], V.TOR_CONNECTION[1])
+                    else:
+                        sock = socket.socket(af, socktype, proto)
                 except OSError:
                     continue
                 sock.settimeout(10)
@@ -340,6 +349,7 @@ class Core:
         self.traffic.put_traffic_up(send_data)
 
     def _initial_connection_check(self, sock, host_port):
+        current_thread().setName('InitCheck')
         sock.settimeout(10)
         try:
             # ヘッダーを受取る
@@ -504,24 +514,33 @@ class Core:
         f_tcp = True
         host_port = new_user.get_host_port()
         af = socket.AF_INET if len(host_port) == 2 else socket.AF_INET6
+        sock = socket.socket(af, socket.SOCK_STREAM)
         try:
-            sock = socket.socket(af, socket.SOCK_STREAM)
             r = sock.connect_ex(host_port)
             if r != 0:
                 f_tcp = False
-            sock.close()
         except OSError:
             f_tcp = False
+        try:
+            sock.close()
+        except OSError:
+            pass
         f_udp = self.ping(user=new_user, f_udp=True)
+        f_changed = False
         # reflect user status
         if f_tcp is not new_user.p2p_accept:
             logging.debug("{} Update TCP accept status [{}>{}]"
                           .format(new_user, new_user.p2p_accept, f_tcp))
             new_user.p2p_accept = f_tcp
+            f_changed = True
         if f_udp is not new_user.p2p_udp_accept:
             logging.debug("{} Update UDP accept status [{}>{}]"
                           .format(new_user, new_user.p2p_udp_accept, f_udp))
             new_user.p2p_udp_accept = f_udp
+            f_changed = True
+        # if f_changed:
+        #    logging.info("{} Change TCP/UDP accept status tcp={} udp={}"
+        #                 .format(new_user, f_tcp, f_udp))
 
     def name2user(self, name):
         for user in self.user:
